Bitwise<T> class
Constructors
-
Bitwise(List<
BitwiseOption< options)T> > -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
options
→ List<
BitwiseOption< T> > -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getBitwiseValue(
T type) → int -
isSet(
int selectedOptions, T option) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
optionToFalse(
int selectedOptions, T option) → int -
optionToTrue(
int selectedOptions, T option) → int -
setAllOptions(
List< T> setOptions) → int -
toggleOption(
int selectedOptions, T option) → int -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited